;#####################################################################################################################################
; _Centered_Msgbox UDF
; AutoItV-ersion: 3.3.14.2
; Author:		  photonbuddy (Org.: _Display_Msg)
; Extended by:	  YellowLab (Center Msgbox-Feature), Cape-City (Topmost Msgbox, Center Textstyle-Feature, GUI Icon)
;#####################################################################################################################################

#include-once
#include <GUIConstantsEx.au3>
#include <WindowsConstants.au3>

;=====================================================================================================================================
; _Centered_Msgbox ($title, $text, $button, $hWin, [$textstyle, [$msgwidth, [$msgheight, [$buttonwidth, [$ntimeout]]]]])
;
; Where:
;
;	$title		 =	The title of the message box
;	$text		 =	The text to be displayed. Long lines will wrap. The text will also be centered.
;	$button		 =	The text for the buttons. Seperate buttons with the pipe (|) character.
;					To set a button as the default button, place the ampersand (&) character before the word.
;					If you put more than 1 ampersand character, the function will fail and return -1, plus set @error to 1
;	$hWin		 =	The handle of the window the message box is to be centered in.
;	$textstyle	 =	The style of the text within the msgbox (0 = left (default), 1 = center, 2 = right)
;	$msgwidth	 =	Width of the displayed window. This value will be automatically increased if the resulting
;					window will not be wide enough to accommodate the buttons requested. Default is 300
;	$msgheight	 =  Height of the displayed window. This is not adjusted. If the text is too big, it will not
;					display it all. Default is 80
;	$buttonwidth =  The width of the button in pixels.  Default is 80
;
;	Success:  		Returns the button pressed, starting at 1, counting from the LEFT. Returns 0 is the
;                 	Message Box was closed via a "CloseGUI" event, i.e. click the close box or press Escape.
;
;	Failure:		Returns -1 if Message Box was not created due to more than 1 default button being set or
;					other GUI error.  Error is set to 1.
;=====================================================================================================================================
Func _Centered_Msgbox ($title, $text, $button, $hWin, $hIcon = 0, $textstyle = 0, $msgwidth = 300, $msgheight = 80, $buttonwidth = 80, $ntimeout = -1)
    Local $nOldOpt = Opt ('GUIOnEventMode', 0)
    Local $buttonarray = StringSplit ($button,"|")
    Local $msgButton[$buttonarray[0] + 1]
    Local $buttoncount, $defbutton = 0, $retvalue, $buttonwork, $buttonxpos, $mmsg
    Local $arTemp = WinGetPos ($hWin)
    If StringInStr ($button, "&", 0, 2) <> 0 Then ;if two buttons are showing focus
        $nOldOpt = Opt ('GUIOnEventMode', $nOldOpt)
        SetError (1)
        Return -1
    EndIf
    If ($buttonwidth + 8) * $buttonarray[0] + 8 > $msgwidth Then $msgwidth = ($buttonwidth + 8) * $buttonarray[0] + 8 ;if button width exceeds window size, resize window
    Local $msggui = GUICreate ($title, $msgwidth, $msgheight, ($arTemp[2] - $msgwidth) / 2 + $arTemp[0] - 3, ($arTemp[3] - $msgheight) / 2 + _
							   $arTemp[1] - 16, BitOr ($WS_POPUPWINDOW, $WS_CAPTION), $WS_EX_TOPMOST, $hWin)
   	GUISetIcon ($hIcon) ;set icon
	If $msggui = 0 Then
        $nOldOpt = Opt ('GUIOnEventMode', $nOldOpt)
        SetError (1)
        Return -1
    EndIf
    Local $hDummy = GUICtrlCreateLabel ($text, 8, 8, $msgwidth - 16, $msgheight - 40, $textstyle)
    $buttonxpos = (($msgwidth / $buttonarray[0]) - ($buttonwidth)) / 2
    For $buttoncount = 0 To $buttonarray[0] - 1
        $buttonwork = $buttonarray[$buttoncount + 1]
        If StringLeft ($buttonwork, 1) = "&" Then
            $defbutton = 0x0001 ;$BS_DEFPUSHBUTTON
            $buttonarray[$buttoncount + 1] = StringTrimLeft ($buttonwork, 1)
        EndIf
        $msgbutton[$buttoncount] = GUICtrlCreateButton($buttonarray[$buttoncount + 1], $buttonxpos + ($buttoncount * $buttonwidth) + _
													   ($buttoncount * $buttonxpos * 2), $msgheight - 32, $buttonwidth, 24, $defbutton)
        $defbutton = 0
    Next
    GUISetState (@SW_SHOW, $msggui)

    Dim $timeout
    If $ntimeout <> -1 Then $timeout = TimerInit()
    While 1
        $mmsg = GUIGetMsg()
        If $mmsg > 2 Then
            $retvalue = $mmsg - $hDummy ;ctrl number of button minus the ctrl number of the label will result in button 1 = 1, button 2 = 2
        Else
        Select
            Case $mmsg = -3 ;$GUI_EVENT_CLOSE = -3
                GUIDelete ($msggui)
                $nOldOpt = Opt ('GUIOnEventMode', $nOldOpt)
                Return 0
            Case Else
                If TimerDiff ($timeout) / 1000 >= $ntimeout AND $ntimeout <> -1 Then
                    GUIDelete ($msggui)
                    $nOldOpt = Opt ('GUIOnEventMode', $nOldOpt)
                    Return 0
                EndIf
        EndSelect
        EndIf
        If $retvalue <> '' Then ExitLoop
    WEnd
    $nOldOpt = Opt ('GUIOnEventMode', $nOldOpt)
    GUIDelete ($msggui)
    Return $retvalue
EndFunc ;==> _Centered_Msgbox()