#include-once

;======================================================================================
; Function Name:		_GDIPlus_PrivateBitmapCreateFromMemoryWithResize
; Description:			Loads an image which is saved as a binary string and converts it to a bitmap or hbitmap incl. resizing
;
; Parameters:    		$bImage:		the binary string which contains any valid image which is supported by GDI+
; Optional:  			$hHBITMAP:		if false a bitmap will be created, if true a hbitmap will be created
;
; Return Value(s):		Success: handle to bitmap or hbitmap, Error: 0
; Error codes:			1: $bImage is not a binary string
;						2: unable to create stream on HGlobal
;						3: unable to create bitmap from stream
;
; Author(s):			UEZ
; Additional Code:		progandy, image resizing by Cape-City
;=======================================================================================
Func _GDIPlus_PrivateBitmapCreateFromMemoryWithResize($dImage, $hHBITMAP = False, $hWidth = False, $hHeight = False)
	If Not IsBinary($dImage) Then Return SetError(1, 0, 0)
	Local $aResult = 0
	Local Const $dMemBitmap = Binary($dImage) ;load image saved in variable (memory) and convert it to binary
	Local Const $iLen = BinaryLen($dMemBitmap) ;get binary length of the image
	Local Const $GMEM_MOVEABLE = 0x0002
	$aResult = DllCall("kernel32.dll", "handle", "GlobalAlloc", "uint", $GMEM_MOVEABLE, "ulong_ptr", $iLen) ;allocates movable memory ($GMEM_MOVEABLE = 0x0002)
	If @error Then Return SetError(4, 0, 0)
	Local Const $hData = $aResult[0]
	$aResult = DllCall("kernel32.dll", "ptr", "GlobalLock", "handle", $hData)
	If @error Then Return SetError(5, 0, 0)
	Local $tMem = DllStructCreate("byte[" & $iLen & "]", $aResult[0]) ;create struct
	DllStructSetData($tMem, 1, $dMemBitmap) ;fill struct with image data
	DllCall("kernel32.dll", "bool", "GlobalUnlock", "handle", $hData) ;decrements the lock count associated with a memory object that was allocated with GMEM_MOVEABLE
	If @error Then Return SetError(6, 0, 0)
	Local Const $hStream = _WinAPI_CreateStreamOnHGlobal($hData) ;creates a stream object that uses an HGLOBAL memory handle to store the stream contents
	If @error Then Return SetError(2, 0, 0)
	Local Const $hBitmap = _GDIPlus_BitmapCreateFromStream($hStream) ;creates a Bitmap object based on an IStream COM interface
	If @error Then Return SetError(3, 0, 0)
	Local $hBitmapResize = $hBitmap
	If $hWidth <> False And $hHeight <> False Then $hBitmapResize = _GDIPlus_ImageResize($hBitmap, $hWidth, $hHeight) ;resize image
	DllCall("oleaut32.dll", "long", "DispCallFunc", "ptr", $hStream, "ulong_ptr", 8 * (1 + @AutoItX64), "uint", 4, "ushort", 23, "uint", 0, "ptr", 0, "ptr", 0, "str", "") ;release memory from $hStream to avoid memory leak
	If $hHBITMAP Then
		Local Const $hHBmp = _GDIPlus_BitmapCreateDIBFromBitmap($hBitmapResize) ;supports GDI transparent color format
		Return $hHBmp
	EndIf
	Return $hBitmapResize
EndFunc   ;==>_GDIPlus_PrivateBitmapCreateFromMemoryWithResize
