#include-once
#include <WinAPI.au3>
#include <WindowsConstants.au3>

;
;
; $KeyPressed has to be global declared as FALSE, befor running _WhichKey_Startup()
; _WhichKey_Startup() has to run once, thereafter $KeyPressed contains always the pressed key
; _WhichKey_Shutdown() has to be run once, when your script is ending
;
; Code Example:
;
; #include <_WhichKeyWasPressed.au3>
;
; Global $KeyPressed = False
; _WhichKey_Startup()
;
; While Sleep(100)
;	If $KeyPressed Then DoSomething()
; WEnd
;
; Func DoSomething()
;	ConsoleWrite ("ASCII Code: " & $KeyPressed & @CRLF)
;	Switch $KeyPressed
;		Case 27
;			_WhichKey_Shutdown()
;			Exit
;	EndSwitch
;	$KeyPressed = False
; EndFunc
;

Func _WhichKey_Startup()

	Global $hmod, $hHook, $hStub_KeyProc

	$hStub_KeyProc = DllCallbackRegister('_KeyProc', 'long', 'int;wparam;lparam')
	$hmod = _WinAPI_GetModuleHandle(0)
	$hHook = _WinAPI_SetWindowsHookEx($WH_KEYBOARD_LL, DllCallbackGetPtr($hStub_KeyProc), $hmod)

EndFunc ;==>_WhichKey_Startup

Func _KeyProc($nCode, $wParam, $lParam)

	Local $tKEYHOOKS = DllStructCreate($tagKBDLLHOOKSTRUCT, $lParam)

	If $nCode < 0 Then Return _WinAPI_CallNextHookEx($hHook, $nCode, $wParam, $lParam)
	If $wParam = $WM_KEYDOWN Then $iKeyPressed = DllStructGetData($tKEYHOOKS, 'vkCode')

	Return _WinAPI_CallNextHookEx($hHook, $nCode, $wParam, $lParam)

EndFunc   ;==>_KeyProc

Func _WhichKey_Shutdown()

	_WinAPI_UnhookWindowsHookEx($hHook)
	DllCallbackFree($hStub_KeyProc)

EndFunc   ;==>_WhichKey_Shutdown
